"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.NetworkSignalsFilter = exports.NetworkSignalsFilterList = void 0;
const helpers_1 = require("./helpers");
class NetworkFilterListItem {
    get combinedRegex() {
        const normalizeRegex = (regex) => {
            return typeof regex === 'string' ? new RegExp(regex) : regex;
        };
        return new RegExp(this.regexes
            .map((val) => normalizeRegex(val))
            .map((r) => r.source)
            .join('|'));
    }
    constructor(regexes) {
        this.regexes = regexes;
    }
    test(value) {
        if (!this.regexes.length) {
            return false;
        }
        return this.combinedRegex.test(value);
    }
    add(...regex) {
        this.regexes.push(...regex);
    }
    addURLLike(...urlLike) {
        const parsedRegexes = urlLike
            .map((domain) => this.urlToRegex(domain))
            .filter((val) => Boolean(val));
        this.add(...parsedRegexes);
    }
    urlToRegex(urlLike) {
        const clean = urlLike.replace(/[.*+?^${}()|[\]\\]/g, '\\$&');
        try {
            return new RegExp(clean);
        }
        catch (e) {
            console.error(`Invalid regex: ${clean}`, e);
        }
    }
}
class NetworkSignalsFilterList {
    constructor(allowList, disallowList) {
        this.allowed = new NetworkFilterListItem(allowList || []);
        this.disallowed = new NetworkFilterListItem(disallowList || []);
        this.disallowedDefaults = new NetworkFilterListItem([
            'api.segment.io',
            'signals.segment.io',
            'cdn.segment.com',
        ]);
    }
    isAllowed(url) {
        const disallowed = this.disallowed.test(url) || this.disallowedDefaults.test(url);
        const allowed = this.allowed.test(url);
        return allowed && !disallowed;
    }
    getRegexes() {
        return {
            allowed: this.allowed.regexes.map((el) => el.toString()),
            disallowed: this.disallowed.regexes.map((el) => el.toString()),
        };
    }
}
exports.NetworkSignalsFilterList = NetworkSignalsFilterList;
class NetworkSignalsFilter {
    constructor(settings) {
        this.settings = settings;
    }
    isAllowed(url) {
        const { networkSignalsFilterList, networkSignalsAllowSameDomain } = this.settings;
        const passesNetworkFilter = networkSignalsFilterList.isAllowed(url);
        const allowedBecauseSameDomain = networkSignalsAllowSameDomain && (0, helpers_1.isSameDomain)(url);
        const allowed = passesNetworkFilter || allowedBecauseSameDomain;
        return allowed;
    }
}
exports.NetworkSignalsFilter = NetworkSignalsFilter;
//# sourceMappingURL=network-signals-filter.js.map